Index: sasmodels/models/_spherepy.py
===================================================================
--- sasmodels/models/_spherepy.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/_spherepy.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -33,5 +33,4 @@
 to the output of the software provided by the NIST (Kline, 2006).
 
-
 References
 ----------
@@ -40,5 +39,17 @@
 John Wiley and Sons, New York, (1955)
 
+Source
+------
+
+`_spherepy.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/_spherepy.py>`_
+`sphere.c <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/sphere.c>`_
+
+Authorship and Verification
+----------------------------
+
+* **Author: P Kienzle** 
+* **Last Modified by:** 
 * **Last Reviewed by:** S King and P Parker **Date:** 2013/09/09 and 2014/01/06
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/adsorbed_layer.py
===================================================================
--- sasmodels/models/adsorbed_layer.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/adsorbed_layer.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -49,4 +49,9 @@
    Layers*, *Macromol. Symp.*, 190 (2002) 33-42.
 
+Source
+------
+
+`adsorbed_layer.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/adsorbed_layer.py>`_
+
 Authorship and Verification
 ----------------------------
@@ -55,4 +60,5 @@
 * **Last Modified by:** Paul Kienzle **Date:** April 14, 2016
 * **Last Reviewed by:** Steve King **Date:** March 18, 2016
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/barbell.py
===================================================================
--- sasmodels/models/barbell.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/barbell.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -76,8 +76,15 @@
 ----------
 
-.. [#] H Kaya, *J. Appl. Cryst.*, 37 (2004) 37 223-230
+.. [#] H Kaya, *J. Appl. Cryst.*, 37 (2004) 223-230
 .. [#] H Kaya and N R deSouza, *J. Appl. Cryst.*, 37 (2004) 508-509 (addenda
    and errata)
-L. Onsager, Ann. New York Acad. Sci. 51, 627-659 (1949).
+.. [#] L. Onsager, *Ann. New York Acad. Sci.*, 51 (1949) 627-659
+
+Source
+------
+
+`barbell.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/barbell.py>`_
+
+`barbell.c <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/barbell.c>`_
 
 Authorship and Verification
@@ -87,4 +94,5 @@
 * **Last Modified by:** Paul Butler **Date:** March 20, 2016
 * **Last Reviewed by:** Richard Heenan **Date:** January 4, 2017
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/bcc_paracrystal.py
===================================================================
--- sasmodels/models/bcc_paracrystal.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/bcc_paracrystal.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -100,4 +100,11 @@
    (Corrections to FCC and BCC lattice structure calculation)
 
+Source
+------
+
+`bcc_paracrystal.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/bcc_paracrystal.py>`_
+
+`bcc_paracrystal.c <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/bcc_paracrystal.c>`_
+
 Authorship and Verification
 ---------------------------
@@ -106,4 +113,5 @@
 * **Last Modified by:** Paul Butler **Date:** September 29, 2016
 * **Last Reviewed by:** Richard Heenan **Date:** March 21, 2016
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/be_polyelectrolyte.py
===================================================================
--- sasmodels/models/be_polyelectrolyte.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/be_polyelectrolyte.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -91,4 +91,9 @@
 .. [#] E Raphael, J F Joanny, *Europhysics Letters*, 11 (1990) 179
 
+Source
+------
+
+`be_polyelectrolyte.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/be_polyelectrolyte.py>`_
+
 Authorship and Verification
 ----------------------------
@@ -97,4 +102,5 @@
 * **Last Modified by:** Paul Butler **Date:** September 25, 2018
 * **Last Reviewed by:** Paul Butler **Date:** September 25, 2018
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/binary_hard_sphere.py
===================================================================
--- sasmodels/models/binary_hard_sphere.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/binary_hard_sphere.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -65,4 +65,11 @@
 .. [#] S R Kline, *J Appl. Cryst.*, 39 (2006) 895
 
+Source
+------
+
+`binary_hard_sphere.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/binary_hard_sphere.py>`_
+
+`binary_hard_sphere.c <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/binary_hard_sphere.c>`_
+
 Authorship and Verification
 ----------------------------
@@ -71,4 +78,5 @@
 * **Last Modified by:** Paul Butler **Date:** March 20, 2016
 * **Last Reviewed by:** Paul Butler **Date:** March 20, 2016
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/broad_peak.py
===================================================================
--- sasmodels/models/broad_peak.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/broad_peak.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -33,4 +33,9 @@
 None.
 
+Source
+------
+
+`broad_peak.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/broad_peak.py>`_
+
 Authorship and Verification
 ----------------------------
@@ -39,4 +44,5 @@
 * **Last Modified by:** Paul kienle **Date:** July 24, 2016
 * **Last Reviewed by:** Richard Heenan **Date:** March 21, 2016
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/capped_cylinder.py
===================================================================
--- sasmodels/models/capped_cylinder.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/capped_cylinder.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -82,5 +82,12 @@
 .. [#] H Kaya and N-R deSouza, *J. Appl. Cryst.*, 37 (2004) 508-509 (addenda
    and errata)
-L. Onsager, Ann. New York Acad. Sci. 51, 627-659 (1949).
+.. [#] L. Onsager, *Ann. New York Acad. Sci.*, 51 (1949) 627-659
+
+Source
+------
+
+`capped_cylinder.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/capped_cylinder.py>`_
+
+`capped_cylinder.c <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/capped_cylinder.c>`_
 
 Authorship and Verification
@@ -90,4 +97,5 @@
 * **Last Modified by:** Paul Butler **Date:** September 30, 2016
 * **Last Reviewed by:** Richard Heenan **Date:** January 4, 2017
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/core_multi_shell.py
===================================================================
--- sasmodels/models/core_multi_shell.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/core_multi_shell.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -39,4 +39,11 @@
    Neutron Scattering*, Plenum Press, New York, 1987.
 
+Source
+------
+
+`core_multi_shell.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/core_multi_shell.py>`_
+
+`core_multi_shell.c <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/core_multi_shell.c>`_
+
 Authorship and Verification
 ----------------------------
@@ -45,4 +52,5 @@
 * **Last Modified by:** Paul Kienzle **Date:** September 12, 2016
 * **Last Reviewed by:** Paul Kienzle **Date:** September 12, 2016
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 from __future__ import division
Index: sasmodels/models/core_shell_bicelle.py
===================================================================
--- sasmodels/models/core_shell_bicelle.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/core_shell_bicelle.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -90,5 +90,12 @@
    =26379>`_
 
-   L. Onsager, Ann. New York Acad. Sci. 51, 627-659 (1949).
+.. [#] L. Onsager, *Ann. New York Acad. Sci.*, 51 (1949) 627-659
+
+Source
+------
+
+`core_shell_bicelle.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/core_shell_bicelle.py>`_
+
+`core_shell_bicelle.c <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/core_shell_bicelle.c>`_
 
 Authorship and Verification
@@ -98,4 +105,5 @@
 * **Last Modified by:** Paul Butler **Date:** September 30, 2016
 * **Last Reviewed by:** Richard Heenan **Date:** January 4, 2017
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/core_shell_bicelle_elliptical.py
===================================================================
--- sasmodels/models/core_shell_bicelle_elliptical.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/core_shell_bicelle_elliptical.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -99,6 +99,12 @@
 ----------
 
-.. [#]
-L. Onsager, Ann. New York Acad. Sci. 51, 627-659 (1949).
+.. [#] L. Onsager, *Ann. New York Acad. Sci.*, 51 (1949) 627-659
+
+Source
+------
+
+`core_shell_bicelle_elliptical.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/core_shell_bicelle_elliptical.py>`_
+
+`core_shell_bicelle_elliptical.c <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/core_shell_bicelle_elliptical.c>`_
 
 Authorship and Verification
@@ -108,4 +114,5 @@
 * **Last Modified by:**  Richard Heenan **Date:** December 14, 2016
 * **Last Reviewed by:**  Paul Kienzle **Date:** Feb 28, 2018
+* **Source added by :**  Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/core_shell_bicelle_elliptical_belt_rough.py
===================================================================
--- sasmodels/models/core_shell_bicelle_elliptical_belt_rough.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/core_shell_bicelle_elliptical_belt_rough.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -111,6 +111,12 @@
 ----------
 
-.. [#]
-L. Onsager, Ann. New York Acad. Sci. 51, 627-659 (1949).
+.. [#] L. Onsager, *Ann. New York Acad. Sci.*, 51 (1949) 627-659
+
+Source
+------
+
+`core_shell_bicelle_elliptical_belt_rough.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/core_shell_bicelle_elliptical_belt_rough.py>`_
+
+`core_shell_bicelle_elliptical_belt_rough.c <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/core_shell_bicelle_elliptical_belt_rough.c>`_
 
 Authorship and Verification
@@ -120,4 +126,5 @@
 * **Last Modified by:**  Richard Heenan new 2d orientation **Date:** October 5, 2017
 * **Last Reviewed by:**  Richard Heenan 2d calc seems agree with 1d **Date:** Nov 2, 2017
+* **Source added by :**  Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/core_shell_cylinder.py
===================================================================
--- sasmodels/models/core_shell_cylinder.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/core_shell_cylinder.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -70,5 +70,12 @@
    1445-1452
 .. [#kline] S R Kline, *J Appl. Cryst.*, 39 (2006) 895
-L. Onsager, Ann. New York Acad. Sci. 51, 627-659 (1949).
+.. [#] L. Onsager, *Ann. New York Acad. Sci.*, 51 (1949) 627-659
+
+Source
+------
+
+`core_shell_cylinder.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/core_shell_cylinder.py>`_
+
+`core_shell_cylinder.c <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/core_shell_cylinder.c>`_
 
 Authorship and Verification
@@ -78,4 +85,5 @@
 * **Last Modified by:** Paul Kienzle **Date:** Aug 8, 2016
 * **Last Reviewed by:** Richard Heenan **Date:** March 18, 2016
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/core_shell_ellipsoid.py
===================================================================
--- sasmodels/models/core_shell_ellipsoid.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/core_shell_ellipsoid.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -88,6 +88,14 @@
 ----------
 see for example:
-Kotlarchyk, M.; Chen, S.-H. J. Chem. Phys., 1983, 79, 2461.
-Berr, S.  J. Phys. Chem., 1987, 91, 4760.
+
+.. [#] Kotlarchyk, M.; Chen, S.-H. *J. Chem. Phys.*, 1983, 79, 2461
+.. [#] Berr, S. *J. Phys. Chem.*, 1987, 91, 4760
+
+Source
+------
+
+`core_shell_ellipsoid.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/core_shell_ellipsoid.py>`_
+
+`core_shell_ellipsoid.c <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/core_shell_ellipsoid.c>`_
 
 Authorship and Verification
@@ -97,4 +105,5 @@
 * **Last Modified by:** Richard Heenan (reparametrised model) **Date:** 2015
 * **Last Reviewed by:** Richard Heenan **Date:** October 6, 2016
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/core_shell_parallelepiped.py
===================================================================
--- sasmodels/models/core_shell_parallelepiped.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/core_shell_parallelepiped.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -173,5 +173,12 @@
    from Proquest <http://search.proquest.com/docview/304915826?accountid
    =26379>`_
-L. Onsager, Ann. New York Acad. Sci. 51, 627-659 (1949).
+.. [#] L. Onsager, *Ann. New York Acad. Sci.*, 51 (1949) 627-659
+
+Source
+------
+
+`core_shell_parallelepiped.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/core_shell_parallelepiped.py>`_
+
+`core_shell_parallelepiped.c <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/core_shell_parallelepiped.c>`_
 
 Authorship and Verification
@@ -183,4 +190,5 @@
 * **Last Reviewed by:** Paul Butler **Date:** May 24, 2018 - documentation
   updated
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/core_shell_sphere.py
===================================================================
--- sasmodels/models/core_shell_sphere.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/core_shell_sphere.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -38,10 +38,4 @@
 effective radius for $S(Q)$ when $P(Q) \cdot S(Q)$ is applied.
 
-References
-----------
-
-A Guinier and G Fournet, *Small-Angle Scattering of X-Rays*,
-John Wiley and Sons, New York, (1955)
-
 Validation
 ----------
@@ -50,4 +44,24 @@
 the output of the software provided by NIST (Kline, 2006). Figure 1 shows a
 comparison of the output of our model and the output of the NIST software.
+
+References
+----------
+
+.. [#] A Guinier and G Fournet, *Small-Angle Scattering of X-Rays*, John Wiley and Sons, New York, (1955)
+
+Source
+------
+
+`core_shell_sphere.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/core_shell_sphere.py>`_
+
+`core_shell_sphere.c <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/core_shell_sphere.c>`_
+
+Authorship and Verification
+----------------------------
+
+* **Author:** 
+* **Last Modified by:** 
+* **Last Reviewed by:** 
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/correlation_length.py
===================================================================
--- sasmodels/models/correlation_length.py	(revision a8072067ae8a224e45d23ba71f663aadbe1ba4a9)
+++ sasmodels/models/correlation_length.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -30,6 +30,18 @@
 ----------
 
-B Hammouda, D L Ho and S R Kline, Insight into Clustering in
-Poly(ethylene oxide) Solutions, Macromolecules, 37 (2004) 6932-6937
+.. [#] B Hammouda, D L Ho and S R Kline, Insight into Clustering in Poly(ethylene oxide) Solutions, Macromolecules, 37 (2004) 6932-6937
+
+Source
+------
+
+`correlation_length.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/correlation_length.py>`_
+
+Authorship and Verification
+----------------------------
+
+* **Author:** 
+* **Last Modified by:** 
+* **Last Reviewed by:** 
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/cylinder.py
===================================================================
--- sasmodels/models/cylinder.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/cylinder.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -96,7 +96,22 @@
 ----------
 
-J. S. Pedersen, Adv. Colloid Interface Sci. 70, 171-210 (1997).
-G. Fournet, Bull. Soc. Fr. Mineral. Cristallogr. 74, 39-113 (1951).
-L. Onsager, Ann. New York Acad. Sci. 51, 627-659 (1949).
+.. [#] J. Pedersen, *Adv. Colloid Interface Sci.*, 70 (1997) 171-210
+.. [#] G. Fournet, *Bull. Soc. Fr. Mineral. Cristallogr.*, 74 (1951) 39-113
+.. [#] L. Onsager, *Ann. New York Acad. Sci.*, 51 (1949) 627-659
+
+Source
+------
+
+`cylinder.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/cylinder.py>`_
+
+`cylinder.c <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/cylinder.c>`_
+
+Authorship and Verification
+----------------------------
+
+* **Author:** 
+* **Last Modified by:** 
+* **Last Reviewed by:** 
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/dab.py
===================================================================
--- sasmodels/models/dab.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/dab.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -31,11 +31,19 @@
 ----------
 
-P Debye, H R Anderson, H Brumberger, *Scattering by an Inhomogeneous Solid. II.
-The Correlation Function and its Application*, *J. Appl. Phys.*, 28(6) (1957) 679
+.. [#] P Debye, H R Anderson, H Brumberger, *Scattering by an Inhomogeneous Solid. II. The Correlation Function and its Application*, *J. Appl. Phys.*, 28(6) (1957) 679
+.. [#] P Debye, A M Bueche, *Scattering by an Inhomogeneous Solid*, *J. Appl. Phys.*, 20 (1949) 518
 
-P Debye, A M Bueche, *Scattering by an Inhomogeneous Solid*, *J. Appl. Phys.*,
-20 (1949) 518
+Source
+------
 
-*2013/09/09 - Description reviewed by King, S and Parker, P.*
+`dab.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/dab.py>`_
+
+Authorship and Verification
+----------------------------
+
+* **Author:** 
+* **Last Modified by:** 
+* **Last Reviewed by:** Steve King & Peter Parker **Date:** September 09, 2013
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
@@ -70,5 +78,5 @@
         scale=10**np.random.uniform(1, 4),
         cor_length=10**np.random.uniform(0.3, 3),
-        #background = 0,
+#        background = 0,
     )
     pars['scale'] /= pars['cor_length']**3
Index: sasmodels/models/ellipsoid.py
===================================================================
--- sasmodels/models/ellipsoid.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/ellipsoid.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -67,6 +67,4 @@
 
 The $\theta$ and $\phi$ parameters are not used for the 1D output.
-
-
 
 Validation
@@ -108,9 +106,13 @@
 ----------
 
-L A Feigin and D I Svergun.
-*Structure Analysis by Small-Angle X-Ray and Neutron Scattering*,
-Plenum Press, New York, 1987.
-
-A. Isihara. J. Chem. Phys. 18(1950) 1446-1449
+.. [#] L A Feigin and D I Svergun. *Structure Analysis by Small-Angle X-Ray and Neutron Scattering*, Plenum Press, New York, 1987
+.. [#] A. Isihara. *J. Chem. Phys.*, 18 (1950) 1446-1449
+
+Source
+------
+
+`ellipsoid.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/ellipsoid.py>`_
+
+`ellipsoid.c <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/ellipsoid.c>`_
 
 Authorship and Verification
@@ -120,4 +122,5 @@
 * **Converted to sasmodels by:** Helen Park **Date:** July 9, 2014
 * **Last Modified by:** Paul Kienzle **Date:** March 22, 2017
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 from __future__ import division
Index: sasmodels/models/elliptical_cylinder.py
===================================================================
--- sasmodels/models/elliptical_cylinder.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/elliptical_cylinder.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -86,7 +86,13 @@
 ----------
 
-L A Feigin and D I Svergun, *Structure Analysis by Small-Angle X-Ray and
-Neutron Scattering*, Plenum, New York, (1987) [see table 3.4]
-L. Onsager, Ann. New York Acad. Sci. 51, 627-659 (1949).
+.. [#] L A Feigin and D I Svergun, *Structure Analysis by Small-Angle X-Ray and Neutron Scattering*, Plenum, New York, (1987) [see table 3.4]
+.. [#] L. Onsager, *Ann. New York Acad. Sci.*, 51 (1949) 627-659
+
+Source
+------
+
+`elliptical_cylinder.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/elliptical_cylinder.py>`_
+
+`elliptical_cylinder.c <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/elliptical_cylinder.c>`_
 
 Authorship and Verification
@@ -96,4 +102,5 @@
 * **Last Modified by:**
 * **Last Reviewed by:**  Richard Heenan - corrected equation in docs **Date:** December 21, 2016
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/fcc_paracrystal.py
===================================================================
--- sasmodels/models/fcc_paracrystal.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/fcc_paracrystal.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -99,4 +99,11 @@
    (Corrections to FCC and BCC lattice structure calculation)
 
+Source
+------
+
+`fcc_paracrystal.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/fcc_paracrystal.py>`_
+
+`fcc_paracrystal.c <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/fcc_paracrystal.c>`_
+
 Authorship and Verification
 ---------------------------
@@ -105,4 +112,5 @@
 * **Last Modified by:** Paul Butler **Date:** September 29, 2016
 * **Last Reviewed by:** Richard Heenan **Date:** March 21, 2016
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/flexible_cylinder.py
===================================================================
--- sasmodels/models/flexible_cylinder.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/flexible_cylinder.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -50,13 +50,24 @@
 ----------
 
-J S Pedersen and P Schurtenberger. *Scattering functions of semiflexible
-polymers with and without excluded volume effects.* Macromolecules,
-29 (1996) 7602-7612
+.. [#] J S Pedersen and P Schurtenberger. *Scattering functions of semiflexible polymers with and without excluded volume effects.* Macromolecules, 29 (1996) 7602-7612
 
 Correction of the formula can be found in
 
-W R Chen, P D Butler and L J Magid, *Incorporating Intermicellar Interactions
-in the Fitting of SANS Data from Cationic Wormlike Micelles.* Langmuir,
-22(15) 2006 6539-6548
+.. [#] W R Chen, P D Butler and L J Magid, *Incorporating Intermicellar Interactions in the Fitting of SANS Data from Cationic Wormlike Micelles.* Langmuir, 22(15) 2006 6539-6548
+
+Source
+------
+
+`flexible_cylinder.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/flexible_cylinder.py>`_
+
+`flexible_cylinder.c <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/flexible_cylinder.c>`_
+
+Authorship and Verification
+----------------------------
+
+* **Author:** 
+* **Last Modified by:** 
+* **Last Reviewed by:** 
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/flexible_cylinder_elliptical.py
===================================================================
--- sasmodels/models/flexible_cylinder_elliptical.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/flexible_cylinder_elliptical.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -74,12 +74,24 @@
 ----------
 
-J S Pedersen and P Schurtenberger. *Scattering functions of semiflexible polymers
-with and without excluded volume effects.* Macromolecules, 29 (1996) 7602-7612
+.. [#] J S Pedersen and P Schurtenberger. *Scattering functions of semiflexible polymers with and without excluded volume effects.* Macromolecules, 29 (1996) 7602-7612
 
 Correction of the formula can be found in
 
-W R Chen, P D Butler and L J Magid, *Incorporating Intermicellar Interactions in
-the Fitting of SANS Data from Cationic Wormlike Micelles.* Langmuir,
-22(15) 2006 6539-6548
+.. [#] W R Chen, P D Butler and L J Magid, *Incorporating Intermicellar Interactions in the Fitting of SANS Data from Cationic Wormlike Micelles.* Langmuir, 22(15) 2006 6539-6548
+
+Source
+------
+
+`flexible_cylinder_elliptical.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/flexible_cylinder_elliptical.py>`_
+
+`flexible_cylinder_elliptical.c <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/flexible_cylinder_elliptical.c>`_
+
+Authorship and Verification
+----------------------------
+
+* **Author:** 
+* **Last Modified by:** 
+* **Last Reviewed by:** 
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/fractal.py
===================================================================
--- sasmodels/models/fractal.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/fractal.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -46,4 +46,11 @@
 .. [#] J Teixeira, *J. Appl. Cryst.*, 21 (1988) 781-785
 
+Source
+------
+
+`fractal.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/fractal.py>`_
+
+`fractal.c <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/fractal.c>`_
+
 Authorship and Verification
 ----------------------------
@@ -53,4 +60,5 @@
 * **Last Modified by:** Paul Butler **Date:** March 12, 2017
 * **Last Reviewed by:** Paul Butler **Date:** March 12, 2017
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 from __future__ import division
Index: sasmodels/models/fractal_core_shell.py
===================================================================
--- sasmodels/models/fractal_core_shell.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/fractal_core_shell.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -51,4 +51,11 @@
 .. [#Kline]  S R Kline, *J Appl. Cryst.*, 39 (2006) 895
 
+Source
+------
+
+`fractal_core_shell.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/fractal_core_shell.py>`_
+
+`fractal_core_shell.c <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/fractal_core_shell.c>`_
+
 Authorship and Verification
 ----------------------------
@@ -57,4 +64,5 @@
 * **Last Modified by:** Paul Butler and Paul Kienzle **Date:** November 27, 2016
 * **Last Reviewed by:** Paul Butler and Paul Kienzle **Date:** November 27, 2016
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/fuzzy_sphere.py
===================================================================
--- sasmodels/models/fuzzy_sphere.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/fuzzy_sphere.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -51,6 +51,20 @@
 ----------
 
-M Stieger, J. S Pedersen, P Lindner, W Richtering, *Langmuir*,
-20 (2004) 7283-7292
+.. [#] M Stieger, J. S Pedersen, P Lindner, W Richtering, *Langmuir*, 20 (2004) 7283-7292
+
+Source
+------
+
+`fuzzy_sphere.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/fuzzy_sphere.py>`_
+
+`fuzzy_sphere.c <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/fuzzy_sphere.c>`_
+
+Authorship and Verification
+----------------------------
+
+* **Author:** 
+* **Last Modified by:** 
+* **Last Reviewed by:** 
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/gauss_lorentz_gel.py
===================================================================
--- sasmodels/models/gauss_lorentz_gel.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/gauss_lorentz_gel.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -32,6 +32,18 @@
 ----------
 
-G Evmenenko, E Theunissen, K Mortensen, H Reynaers, *Polymer*,
-42 (2001) 2907-2913
+.. [#] G Evmenenko, E Theunissen, K Mortensen, H Reynaers, *Polymer*, 42 (2001) 2907-2913
+
+Source
+------
+
+`gauss_lorentz_gel.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/gauss_lorentz_gel.py>`_
+
+Authorship and Verification
+----------------------------
+
+* **Author:** 
+* **Last Modified by:** 
+* **Last Reviewed by:** 
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/gaussian_peak.py
===================================================================
--- sasmodels/models/gaussian_peak.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/gaussian_peak.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -26,4 +26,17 @@
 
 None.
+
+Source
+------
+
+`gaussian_peak.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/gaussian_peak.py>`_
+
+Authorship and Verification
+----------------------------
+
+* **Author:** 
+* **Last Modified by:** 
+* **Last Reviewed by:** 
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/gel_fit.py
===================================================================
--- sasmodels/models/gel_fit.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/gel_fit.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -37,9 +37,22 @@
 ----------
 
-Mitsuhiro Shibayama, Toyoichi Tanaka, Charles C Han,
-*J. Chem. Phys.* 1992, 97 (9), 6829-6841
+.. [#] Mitsuhiro Shibayama, Toyoichi Tanaka, Charles C Han, *J. Chem. Phys.* 1992, 97 (9), 6829-6841
 
-Simon Mallam, Ferenc Horkay, Anne-Marie Hecht, Adrian R Rennie, Erik Geissler,
-*Macromolecules* 1991, 24, 543-548
+.. [#] Simon Mallam, Ferenc Horkay, Anne-Marie Hecht, Adrian R Rennie, Erik Geissler, *Macromolecules* 1991, 24, 543-548
+
+Source
+------
+
+`gel_fit.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/gel_fit.py>`_
+
+`gel_fit.c <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/gel_fit.c>`_
+
+Authorship and Verification
+----------------------------
+
+* **Author:** 
+* **Last Modified by:** 
+* **Last Reviewed by:** 
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/guinier.py
===================================================================
--- sasmodels/models/guinier.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/guinier.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -46,6 +46,18 @@
 ----------
 
-A Guinier and G Fournet, *Small-Angle Scattering of X-Rays*,
-John Wiley & Sons, New York (1955)
+.. [#] A Guinier and G Fournet, *Small-Angle Scattering of X-Rays*, John Wiley & Sons, New York (1955)
+
+Source
+------
+
+`guinier.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/guinier.py>`_
+
+Authorship and Verification
+----------------------------
+
+* **Author:** 
+* **Last Modified by:** 
+* **Last Reviewed by:** 
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/guinier_porod.py
===================================================================
--- sasmodels/models/guinier_porod.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/guinier_porod.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -60,7 +60,19 @@
 ---------
 
-B Hammouda, *A new Guinier-Porod model, J. Appl. Cryst.*, (2010), 43, 716-719
+.. [#] B Hammouda, *A new Guinier-Porod model, J. Appl. Cryst.*, (2010), 43, 716-719
+.. [#] B Hammouda, *Analysis of the Beaucage model, J. Appl. Cryst.*, (2010), 43, 1474-1478
 
-B Hammouda, *Analysis of the Beaucage model, J. Appl. Cryst.*, (2010), 43, 1474-1478
+Source
+------
+
+`guinier_porod.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/guinier_porod.py>`_
+
+Authorship and Verification
+----------------------------
+
+* **Author:** 
+* **Last Modified by:** 
+* **Last Reviewed by:** 
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/hardsphere.py
===================================================================
--- sasmodels/models/hardsphere.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/hardsphere.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -39,5 +39,18 @@
 ----------
 
-J K Percus, J Yevick, *J. Phys. Rev.*, 110, (1958) 1
+.. [#] J K Percus, J Yevick, *J. Phys. Rev.*, 110, (1958) 1
+
+Source
+------
+
+`hardsphere.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/hardsphere.py>`_
+
+Authorship and Verification
+----------------------------
+
+* **Author:** 
+* **Last Modified by:** 
+* **Last Reviewed by:** 
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/hayter_msa.py
===================================================================
--- sasmodels/models/hayter_msa.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/hayter_msa.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -37,7 +37,21 @@
 ----------
 
-J B Hayter and J Penfold, *Molecular Physics*, 42 (1981) 109-118
+.. [#] J B Hayter and J Penfold, *Molecular Physics*, 42 (1981) 109-118
+.. [#] J P Hansen and J B Hayter, *Molecular Physics*, 46 (1982) 651-656
 
-J P Hansen and J B Hayter, *Molecular Physics*, 46 (1982) 651-656
+Source
+------
+
+`hayter_msa.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/hayter_msa.py>`_
+
+`hayter_msa.c <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/hayter_msa.c>`_
+
+Authorship and Verification
+----------------------------
+
+* **Author:** 
+* **Last Modified by:** 
+* **Last Reviewed by:** 
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/hollow_cylinder.py
===================================================================
--- sasmodels/models/hollow_cylinder.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/hollow_cylinder.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -60,5 +60,12 @@
 .. [#] L A Feigin and D I Svergun, *Structure Analysis by Small-Angle X-Ray and
    Neutron Scattering*, Plenum Press, New York, (1987)
-L. Onsager, Ann. New York Acad. Sci. 51, 627-659 (1949).
+.. [#] L. Onsager, *Ann. New York Acad. Sci.*, 51 (1949) 627-659
+
+Source
+------
+
+`hollow_cylinder.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/hollow_cylinder.py>`_
+
+`hollow_cylinder.c <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/hollow_cylinder.c>`_
 
 Authorship and Verification
@@ -69,4 +76,5 @@
    (corrected VR calculation)
 * **Last Reviewed by:** Paul Butler **Date:** September 06, 2018
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 from __future__ import division
Index: sasmodels/models/hollow_rectangular_prism.py
===================================================================
--- sasmodels/models/hollow_rectangular_prism.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/hollow_rectangular_prism.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -98,6 +98,12 @@
 
 .. [#Nayuk2012] R Nayuk and K Huber, *Z. Phys. Chem.*, 226 (2012) 837-854
-L. Onsager, Ann. New York Acad. Sci. 51, 627-659 (1949).
+.. [#] L. Onsager, *Ann. New York Acad. Sci.*, 51 (1949) 627-659
 
+Source
+------
+
+`hollow_rectangular_prism.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/hollow_rectangular_prism.py>`_
+
+`hollow_rectangular_prism.c <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/hollow_rectangular_prism.c>`_
 
 Authorship and Verification
@@ -107,4 +113,5 @@
 * **Last Modified by:** Paul Kienzle **Date:** December 14, 2017
 * **Last Reviewed by:** Paul Butler **Date:** September 06, 2018
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/hollow_rectangular_prism_thin_walls.py
===================================================================
--- sasmodels/models/hollow_rectangular_prism_thin_walls.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/hollow_rectangular_prism_thin_walls.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -72,6 +72,12 @@
 
 .. [#Nayuk2012] R Nayuk and K Huber, *Z. Phys. Chem.*, 226 (2012) 837-854
-L. Onsager, Ann. New York Acad. Sci. 51, 627-659 (1949).
+.. [#] L. Onsager, *Ann. New York Acad. Sci.*, 51 (1949) 627-659
 
+Source
+------
+
+`hollow_rectangular_prism_thin_walls.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/hollow_rectangular_prism_thin_walls.py>`_
+
+`hollow_rectangular_prism_thin_walls.c <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/hollow_rectangular_prism_thin_walls.c>`_
 
 Authorship and Verification
@@ -81,4 +87,5 @@
 * **Last Modified by:** Paul Kienzle **Date:** October 15, 2016
 * **Last Reviewed by:** Paul Butler **Date:** September 07, 2018
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/lamellar.py
===================================================================
--- sasmodels/models/lamellar.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/lamellar.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -40,7 +40,19 @@
 ----------
 
-F Nallet, R Laversanne, and D Roux, J. Phys. II France, 3, (1993) 487-502
+.. [#] F Nallet, R Laversanne, and D Roux, *J. Phys. II France*, 3, (1993) 487-502
+.. [#] J Berghausen, J Zipfel, P Lindner, W Richtering, *J. Phys. Chem. B*, 105, (2001) 11081-11088
 
-also in J. Phys. Chem. B, 105, (2001) 11081-11088
+Source
+------
+
+`lamellar.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/lamellar.py>`_
+
+Authorship and Verification
+----------------------------
+
+* **Author:** 
+* **Last Modified by:** 
+* **Last Reviewed by:** 
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/lamellar_hg.py
===================================================================
--- sasmodels/models/lamellar_hg.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/lamellar_hg.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -38,12 +38,23 @@
 .. math:: q = \sqrt{q_x^2 + q_y^2}
 
+
 References
 ----------
 
-F Nallet, R Laversanne, and D Roux, J. Phys. II France, 3, (1993) 487-502
+.. [#] F Nallet, R Laversanne, and D Roux, *J. Phys. II France*, 3, (1993) 487-502
+.. [#] J Berghausen, J Zipfel, P Lindner, W Richtering, *J. Phys. Chem. B*, 105, (2001) 11081-11088
 
-also in J. Phys. Chem. B, 105, (2001) 11081-11088
+Source
+------
 
-*2014/04/17 - Description reviewed by S King and P Butler.*
+`lamellar_hg.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/lamellar_hg.py>`_
+
+Authorship and Verification
+----------------------------
+
+* **Author:** 
+* **Last Modified by:** 
+* **Last Reviewed by:** S King and P Butler **Date** April 17, 2014
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/lamellar_hg_stack_caille.py
===================================================================
--- sasmodels/models/lamellar_hg_stack_caille.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/lamellar_hg_stack_caille.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -69,7 +69,21 @@
 ----------
 
-F Nallet, R Laversanne, and D Roux, J. Phys. II France, 3, (1993) 487-502
+.. [#] F Nallet, R Laversanne, and D Roux, *J. Phys. II France*, 3, (1993) 487-502
+.. [#] J Berghausen, J Zipfel, P Lindner, W Richtering, *J. Phys. Chem. B*, 105, (2001) 11081-11088
 
-also in J. Phys. Chem. B, 105, (2001) 11081-11088
+Source
+------
+
+`lamellar_hg_stack_caille.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/lamellar_hg_stack_caille.py>`_
+
+`lamellar_hg_stack_caille.c <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/lamellar_hg_stack_caille.c>`_
+
+Authorship and Verification
+----------------------------
+
+* **Author:** 
+* **Last Modified by:** 
+* **Last Reviewed by:** 
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/lamellar_stack_caille.py
===================================================================
--- sasmodels/models/lamellar_stack_caille.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/lamellar_stack_caille.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -61,10 +61,25 @@
 
 
+
 References
 ----------
 
-F Nallet, R Laversanne, and D Roux, J. Phys. II France, 3, (1993) 487-502
+.. [#] F Nallet, R Laversanne, and D Roux, *J. Phys. II France*, 3, (1993) 487-502
+.. [#] J Berghausen, J Zipfel, P Lindner, W Richtering, *J. Phys. Chem. B*, 105, (2001) 11081-11088
 
-also in J. Phys. Chem. B, 105, (2001) 11081-11088
+Source
+------
+
+`lamellar_stack_caille.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/lamellar_stack_caille.py>`_
+
+`lamellar_stack_caille.c <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/lamellar_stack_caille.c>`_
+
+Authorship and Verification
+----------------------------
+
+* **Author:** 
+* **Last Modified by:** 
+* **Last Reviewed by:** 
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/lamellar_stack_paracrystal.py
===================================================================
--- sasmodels/models/lamellar_stack_paracrystal.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/lamellar_stack_paracrystal.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -88,8 +88,21 @@
 ---------
 
-M Bergstrom, J S Pedersen, P Schurtenberger, S U Egelhaaf,
-*J. Phys. Chem. B*, 103 (1999) 9888-9897
+.. [#] M Bergstrom, J S Pedersen, P Schurtenberger, S U Egelhaaf, *J. Phys. Chem. B*, 103 (1999) 9888-9897
+
+Source
+------
+
+`lamellar_stack_paracrystal.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/lamellar_stack_paracrystal.py>`_
+
+`lamellar_stack_paracrystal.c <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/lamellar_stack_paracrystal.c>`_
+
+Authorship and Verification
+----------------------------
+
+* **Author:** 
+* **Last Modified by:** 
+* **Last Reviewed by:** 
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
-
 import numpy as np
 from numpy import inf
Index: sasmodels/models/line.py
===================================================================
--- sasmodels/models/line.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/line.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -22,5 +22,17 @@
 
 None.
-"""
+
+Source
+------
+
+`line.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/line.py>`_
+
+Authorship and Verification
+----------------------------
+
+* **Author:** 
+* **Last Modified by:** 
+* **Last Reviewed by:** 
+* **Source added by :** Steve King **Date:** March 25, 2019"""
 
 import numpy as np
Index: sasmodels/models/linear_pearls.py
===================================================================
--- sasmodels/models/linear_pearls.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/linear_pearls.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -29,7 +29,20 @@
 ----------
 
-A V Dobrynin, M Rubinstein and S P Obukhov, *Macromol.*,
-29 (1996) 2974-2979
-"""
+.. [#] A V Dobrynin, M Rubinstein and S P Obukhov, *Macromol.*, 29 (1996) 2974-2979
+
+Source
+------
+
+`linear_pearls.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/linear_pearls.py>`_
+
+`linear_pearls.c <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/linear_pearls.c>`_
+
+Authorship and Verification
+----------------------------
+
+* **Author:** 
+* **Last Modified by:** 
+* **Last Reviewed by:** 
+* **Source added by :** Steve King **Date:** March 25, 2019"""
 
 import numpy as np
Index: sasmodels/models/lorentz.py
===================================================================
--- sasmodels/models/lorentz.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/lorentz.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -20,7 +20,18 @@
 ----------
 
-L.S. Qrnstein and F. Zernike, *Proc. Acad. Sci. Amsterdam* 17, 793 (1914), and
-*Z. Phys.* 19, 134 (1918), and 27, 761 {1926); referred to as QZ.
-"""
+.. [#] L.S. Qrnstein and F. Zernike, *Proc. Acad. Sci. Amsterdam* 17, 793 (1914), and *Z. Phys.* 19, 134 (1918), and 27, 761 {1926); referred to as QZ.
+
+Source
+------
+
+`lorentz.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/lorentz.py>`_
+
+Authorship and Verification
+----------------------------
+
+* **Author:** 
+* **Last Modified by:** 
+* **Last Reviewed by:** 
+* **Source added by :** Steve King **Date:** March 25, 2019"""
 
 import numpy as np
Index: sasmodels/models/mass_fractal.py
===================================================================
--- sasmodels/models/mass_fractal.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/mass_fractal.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -49,7 +49,20 @@
 ----------
 
-D Mildner and P Hall, *J. Phys. D: Appl. Phys.*,
-19 (1986) 1535-1545 Equation(9)
-"""
+.. [#] D Mildner and P Hall, *J. Phys. D: Appl. Phys.*, 19 (1986) 1535-1545 Equation(9)
+
+Source
+------
+
+`mass_fractal.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/mass_fractal.py>`_
+
+`mass_fractal.c <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/mass_fractal.c>`_
+
+Authorship and Verification
+----------------------------
+
+* **Author:** 
+* **Last Modified by:** 
+* **Last Reviewed by:** 
+* **Source added by :** Steve King **Date:** March 25, 2019"""
 
 import numpy as np
Index: sasmodels/models/mass_surface_fractal.py
===================================================================
--- sasmodels/models/mass_surface_fractal.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/mass_surface_fractal.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -55,9 +55,18 @@
    35 (1987) 2361-2364 Equation(2)
 
+Source
+------
+
+`mass_surface_fractal.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/mass_surface_fractal.py>`_
+
+`mass_surface_fractal.c <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/mass_surface_fractal.c>`_
+
 Authorship and Verification
 ----------------------------
 
-* **Converted to sasmodels by:** Piotr Rozyczko **Date:** Jan 20, 2016
+* **Author:** Piotr Rozyczko **Date:** Jan 20, 2016
+* **Last Modified by:** 
 * **Last Reviewed by:** Richard Heenan **Date:** May 30, 2018
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/mono_gauss_coil.py
===================================================================
--- sasmodels/models/mono_gauss_coil.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/mono_gauss_coil.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -45,11 +45,22 @@
 ----------
 
-P Debye, *J. Phys. Colloid. Chem.*, 51 (1947) 18.
+.. [#] P Debye, *J. Phys. Colloid. Chem.*, 51 (1947) 18.
+.. [#] R J Roe, *Methods of X-Ray and Neutron Scattering in Polymer Science*, Oxford University Press, New York (2000).
+.. [#] http://www.ncnr.nist.gov/staff/hammouda/distance_learning/chapter_28.pdf
 
-R J Roe, *Methods of X-Ray and Neutron Scattering in Polymer Science*,
-Oxford University Press, New York (2000).
+Source
+------
 
-http://www.ncnr.nist.gov/staff/hammouda/distance_learning/chapter_28.pdf
-"""
+`mono_gauss_coil.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/mono_gauss_coil.py>`_
+
+`mono_gauss_coil.c <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/mono_gauss_coil.c>`_
+
+Authorship and Verification
+----------------------------
+
+* **Author:** 
+* **Last Modified by:** 
+* **Last Reviewed by:** 
+* **Source added by :** Steve King **Date:** March 25, 2019"""
 
 import numpy as np
Index: sasmodels/models/multilayer_vesicle.py
===================================================================
--- sasmodels/models/multilayer_vesicle.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/multilayer_vesicle.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -100,4 +100,11 @@
    R Zana and M Dekker, New York, (1987).
 
+Source
+------
+
+`multilayer_vesicle.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/multilayer_vesicle.py>`_
+
+`multilayer_vesicle.c <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/multilayer_vesicle.c>`_
+
 Authorship and Verification
 ----------------------------
@@ -107,4 +114,5 @@
 * **Last Modified by:** Paul Kienzle **Date:** Feb 7, 2017
 * **Last Reviewed by:** Paul Butler **Date:** March 12, 2017
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/onion.py
===================================================================
--- sasmodels/models/onion.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/onion.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -170,7 +170,20 @@
 ----------
 
-L A Feigin and D I Svergun,
-*Structure Analysis by Small-Angle X-Ray and Neutron Scattering*,
-Plenum Press, New York, 1987.
+.. [#] L A Feigin and D I Svergun, *Structure Analysis by Small-Angle X-Ray and Neutron Scattering*, Plenum Press, New York, 1987.
+
+Source
+------
+
+`onion.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/onion.py>`_
+
+`onion.c <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/onion.c>`_
+
+Authorship and Verification
+----------------------------
+
+* **Author:** 
+* **Last Modified by:** 
+* **Last Reviewed by:** 
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/parallelepiped.py
===================================================================
--- sasmodels/models/parallelepiped.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/parallelepiped.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -180,5 +180,12 @@
    14 (1961) 185-211
 .. [#] R Nayuk and K Huber, *Z. Phys. Chem.*, 226 (2012) 837-854
-L. Onsager, Ann. New York Acad. Sci. 51, 627-659 (1949).
+.. [#] L. Onsager, *Ann. New York Acad. Sci.*, 51 (1949) 627-659
+
+Source
+------
+
+`parallelepiped.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/parallelepiped.py>`_
+
+`parallelepiped.c <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/parallelepiped.c>`_
 
 Authorship and Verification
@@ -189,4 +196,5 @@
 * **Last Reviewed by:**  Miguel Gonzales and Paul Butler **Date:** May 24,
   2018 - documentation updated
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/peak_lorentz.py
===================================================================
--- sasmodels/models/peak_lorentz.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/peak_lorentz.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -26,4 +26,19 @@
 
 None.
+
+Source
+------
+
+`peak_lorentz.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/peak_lorentz.py>`_
+
+`peak_lorentz.c <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/peak_lorentz.c>`_
+
+Authorship and Verification
+----------------------------
+
+* **Author:** 
+* **Last Modified by:** 
+* **Last Reviewed by:** 
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/pearl_necklace.py
===================================================================
--- sasmodels/models/pearl_necklace.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/pearl_necklace.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -51,7 +51,22 @@
 ----------
 
-R Schweins and K Huber, *Particle Scattering Factor of Pearl Necklace Chains*,
+.. [#] R Schweins and K Huber, *Particle Scattering Factor of Pearl Necklace Chains*,
 *Macromol. Symp.* 211 (2004) 25-42 2004
-L. Onsager, Ann. New York Acad. Sci. 51, 627-659 (1949).
+.. [#] L. Onsager, *Ann. New York Acad. Sci.*, 51 (1949) 627-659
+
+Source
+------
+
+`pearl_necklace.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/pearl_necklace.py>`_
+
+`pearl_necklace.c <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/pearl_necklace.c>`_
+
+Authorship and Verification
+----------------------------
+
+* **Author:** 
+* **Last Modified by:** 
+* **Last Reviewed by:** 
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/poly_gauss_coil.py
===================================================================
--- sasmodels/models/poly_gauss_coil.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/poly_gauss_coil.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -43,14 +43,23 @@
 ----------
 
-O Glatter and O Kratky (editors), *Small Angle X-ray Scattering*,
-Academic Press, (1982) Page 404.
+.. [#] O Glatter and O Kratky (editors), *Small Angle X-ray Scattering*, Academic Press, (1982) Page 404
+.. [#] J S Higgins, H C Benoit, *Polymers and Neutron Scattering*, Oxford Science Publications, (1996)
+.. [#] S M King, *Small Angle Neutron Scattering* in *Modern Techniques for Polymer Characterisation*, Wiley, (1999)
+.. [#] http://www.ncnr.nist.gov/staff/hammouda/distance_learning/chapter_28.pdf
 
-J S Higgins, H C Benoit, *Polymers and Neutron Scattering*,
-Oxford Science Publications, (1996).
+Source
+------
 
-S M King, *Small Angle Neutron Scattering* in *Modern Techniques for
-Polymer Characterisation*, Wiley, (1999).
+`poly_gauss_coil.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/poly_gauss_coil.py>`_
 
-http://www.ncnr.nist.gov/staff/hammouda/distance_learning/chapter_28.pdf
+`poly_gauss_coil.c <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/poly_gauss_coil.c>`_
+
+Authorship and Verification
+----------------------------
+
+* **Author:** 
+* **Last Modified by:** 
+* **Last Reviewed by:** 
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/polymer_excl_volume.py
===================================================================
--- sasmodels/models/polymer_excl_volume.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/polymer_excl_volume.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -108,13 +108,23 @@
 ----------
 
-H Benoit, *Comptes Rendus*, 245 (1957) 2244-2247
+.. [#] H Benoit, *Comptes Rendus*, 245 (1957) 2244-2247
+.. [#] B Hammouda, *SANS from Homogeneous Polymer Mixtures - A Unified Overview, Advances in Polym. Sci.* 106 (1993) 87-133
+.. [#] M Hore et al, *Co-Nonsolvency of Poly(n-isopropylacrylamide) in Deuterated Water/Ethanol Mixtures* 46 (2013) 7894-7901
+.. [#] B Hammouda & M-H Kim, *The empirical core-chain model* 247 (2017) 434-440
 
-B Hammouda, *SANS from Homogeneous Polymer Mixtures - A Unified Overview,
-Advances in Polym. Sci.* 106 (1993) 87-133
+Source
+------
 
-M Hore et al, *Co-Nonsolvency of Poly(n-isopropylacrylamide) in Deuterated
-Water/Ethanol Mixtures* 46 (2013) 7894-7901
+`polymer_excl_volume.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/polymer_excl_volume.py>`_
 
-B Hammouda & M-H Kim, *The empirical core-chain model* 247 (2017) 434-440
+`polymer_excl_volume.c <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/polymer_excl_volume.c>`_
+
+Authorship and Verification
+----------------------------
+
+* **Author:** 
+* **Last Modified by:** 
+* **Last Reviewed by:** 
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/polymer_micelle.py
===================================================================
--- sasmodels/models/polymer_micelle.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/polymer_micelle.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -68,10 +68,20 @@
 ----------
 
-J Pedersen, *J. Appl. Cryst.*, 33 (2000) 637-640
+.. [#] J Pedersen, *J. Appl. Cryst.*, 33 (2000) 637-640
 
-* **Modified by:** Richard Heenan **Date:** March 20, 2016
-* **Verified by:** Paul Kienzle **Date:** November 29, 2017
-* **Description modified by:** Paul Kienzle **Date:** November 29, 2017
-* **Description reviewed by:** Steve King **Date:** November 30, 2017
+Source
+------
+
+`polymer_micelle.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/polymer_micelle.py>`_
+
+`polymer_micelle.c <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/polymer_micelle.c>`_
+
+Authorship and Verification
+----------------------------
+
+* **Translated by   :** Richard Heenan **Date:** March 20, 2016
+* **Last modified by:** Paul Kienzle **Date:** November 29, 2017
+* **Last reviewed by:** Steve King **Date:** November 30, 2017
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/porod.py
===================================================================
--- sasmodels/models/porod.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/porod.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -18,8 +18,19 @@
 ----------
 
-G Porod. *Kolloid Zeit*. 124 (1951) 83.
+.. [#] G Porod. *Kolloid Zeit*. 124 (1951) 83
+.. [#] L A Feigin, D I Svergun, G W Taylor. *Structure Analysis by Small-Angle X-ray and Neutron Scattering*. Springer. (1987)
 
-L A Feigin, D I Svergun, G W Taylor. *Structure Analysis by Small-Angle
-X-ray and Neutron Scattering*. Springer. (1987)
+Source
+------
+
+`porod.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/porod.py>`_
+
+Authorship and Verification
+----------------------------
+
+* **Author:** 
+* **Last Modified by:** 
+* **Last Reviewed by:** 
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/power_law.py
===================================================================
--- sasmodels/models/power_law.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/power_law.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -25,4 +25,17 @@
 
 None.
+
+Source
+------
+
+`power_law.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/power_law.py>`_
+
+Authorship and Verification
+----------------------------
+
+* **Author:** 
+* **Last Modified by:** 
+* **Last Reviewed by:** 
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/pringle.py
===================================================================
--- sasmodels/models/pringle.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/pringle.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -40,11 +40,21 @@
 ---------
 
-Karen Edler, Universtiy of Bath, Private Communication. 2012.
-Derivation by Stefan Alexandru Rautu.
-L. Onsager, Ann. New York Acad. Sci. 51, 627-659 (1949).
+.. [#] Karen Edler, Universtiy of Bath, Private Communication. 2012. Derivation by Stefan Alexandru Rautu.
+.. [#] L. Onsager, *Ann. New York Acad. Sci.*, 51 (1949) 627-659
+
+Source
+------
+
+`pringle.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/pringle.py>`_
+
+`pringle.c <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/pringle.c>`_
+
+Authorship and Verification
+----------------------------
 
 * **Author:** Andrew Jackson **Date:** 2008
 * **Last Modified by:** Wojciech Wpotrzebowski **Date:** March 20, 2016
 * **Last Reviewed by:** Andrew Jackson **Date:** September 26, 2016
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/rectangular_prism.py
===================================================================
--- sasmodels/models/rectangular_prism.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/rectangular_prism.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -96,10 +96,22 @@
 ----------
 
-P Mittelbach and G Porod, *Acta Physica Austriaca*, 14 (1961) 185-211
+.. [#] P Mittelbach and G Porod, *Acta Physica Austriaca*, 14 (1961) 185-211
+.. [#] R Nayuk and K Huber, *Z. Phys. Chem.*, 226 (2012) 837-854
+.. [#] L. Onsager, *Ann. New York Acad. Sci.*, 51 (1949) 627-659
 
-R Nayuk and K Huber, *Z. Phys. Chem.*, 226 (2012) 837-854
+Source
+------
 
-L. Onsager, Ann. New York Acad. Sci. 51, 627-659 (1949).
+`rectangular_prism.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/rectangular_prism.py>`_
 
+`rectangular_prism.c <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/rectangular_prism.c>`_
+
+Authorship and Verification
+----------------------------
+
+* **Author:** 
+* **Last Modified by:** 
+* **Last Reviewed by:** 
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/rpa.py
===================================================================
--- sasmodels/models/rpa.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/rpa.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -63,10 +63,14 @@
 ----------
 
-A Z Akcasu, R Klein and B Hammouda, *Macromolecules*, 26 (1993) 4136.
+.. [#] A Z Akcasu, R Klein and B Hammouda, *Macromolecules*, 26 (1993) 4136
+.. [#] B. Hammouda, *Advances in Polymer Science* 106 (1993) 87
+.. [#] B. Hammouda, *SANS Toolbox* https://www.ncnr.nist.gov/staff/hammouda/the_sans_toolbox.pdf.
 
-B. Hammouda, *Advances in Polymer Science* 106 (1993) 87.
+Source
+------
 
-B. Hammouda, *SANS Toolbox*
-https://www.ncnr.nist.gov/staff/hammouda/the_sans_toolbox.pdf.
+`rpa.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/rpa.py>`_
+
+`rpa.c <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/rpa.c>`_
 
 Authorship and Verification
@@ -77,4 +81,5 @@
 * **Last Modified by:** Paul Butler **Date:** March 12, 2017
 * **Last Reviewed by:** Paul Butler **Date:** March 12, 2017
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/sc_paracrystal.py
===================================================================
--- sasmodels/models/sc_paracrystal.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/sc_paracrystal.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -26,5 +26,5 @@
 
 Equation (16) of the 1987 reference\ [#CIT1987]_ is used to calculate $Z(q)$,
-using equations (13)-(15) from the 1987 paper\ [#CIT1987]_ for $Z1$, $Z2$, and
+using equations (13)-(15) from the 1987 paper\ [#CIT1990]_ for $Z1$, $Z2$, and
 $Z3$.
 
@@ -98,8 +98,13 @@
 ---------
 
-.. [#CIT1987] Hideki Matsuoka et. al. *Physical Review B*, 36 (1987) 1754-1765
-   (Original Paper)
-.. [#CIT1990] Hideki Matsuoka et. al. *Physical Review B*, 41 (1990) 3854 -3856
-   (Corrections to FCC and BCC lattice structure calculation)
+.. [#CIT1987] Hideki Matsuoka et. al. *Physical Review B*, 36 (1987) 1754-1765 (Original Paper)
+.. [#CIT1990] Hideki Matsuoka et. al. *Physical Review B*, 41 (1990) 3854 -3856 (Corrections to FCC and BCC lattice structure calculation)
+
+Source
+------
+
+`sc_paracrystal.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/sc_paracrystal.py>`_
+
+`sc_paracrystal.c <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/sc_paracrystal.c>`_
 
 Authorship and Verification
@@ -107,6 +112,7 @@
 
 * **Author:** NIST IGOR/DANSE **Date:** pre 2010
-* **Last Modified by:** Paul Butler **Date:** September 29, 2016
+* **Last Modified by:** Steve King **Date:** March 25, 2019
 * **Last Reviewed by:** Richard Heenan **Date:** March 21, 2016
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/sphere.py
===================================================================
--- sasmodels/models/sphere.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/sphere.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -37,8 +37,20 @@
 ----------
 
-A Guinier and G. Fournet, *Small-Angle Scattering of X-Rays*,
-John Wiley and Sons, New York, (1955)
+.. [#] A Guinier and G. Fournet, *Small-Angle Scattering of X-Rays*, John Wiley and Sons, New York, (1955)
 
+Source
+------
+
+`sphere.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/sphere.py>`_
+
+`sphere.c <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/sphere.c>`_
+
+Authorship and Verification
+----------------------------
+
+* **Author:** 
+* **Last Modified by:** 
 * **Last Reviewed by:** S King and P Parker **Date:** 2013/09/09 and 2014/01/06
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/spherical_sld.py
===================================================================
--- sasmodels/models/spherical_sld.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/spherical_sld.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -14,5 +14,5 @@
     Example SLD profile
 
-Unlike the <onion> model (using an analytical integration), the interfacial
+Unlike the :ref:`onion` model (using an analytical integration), the interfacial
 shells here are sub-divided and numerically integrated assuming each
 sub-shell is described by a line function, with *n_steps* sub-shells per
@@ -90,5 +90,5 @@
     \end{cases}
 
-Power-Law
+Power-Law:
 
 .. math::
@@ -103,4 +103,5 @@
 
 .. math::
+
     \rho_{{inter}_i} (r) = \begin{cases}
     B \text{erf} \Big( \frac { A(r - r_{\text{flat}_i})}
@@ -185,4 +186,10 @@
    and Neutron Scattering, Plenum Press, New York, (1987)
 
+Source
+------
+
+`spherical_sld.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/spherical_sld.py>`_
+
+`spherical_sld.c <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/spherical_sld.c>`_
 
 Authorship and Verification
@@ -192,4 +199,5 @@
 * **Last Modified by:** Paul Kienzle **Date:** Dec 20, 2016
 * **Last Reviewed by:** Paul Butler **Date:** September 8, 2018
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/squarewell.py
===================================================================
--- sasmodels/models/squarewell.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/squarewell.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -44,5 +44,18 @@
 ----------
 
-R V Sharma, K C Sharma, *Physica*, 89A (1977) 213.
+.. [#] R V Sharma, K C Sharma, *Physica*, 89A (1977) 213
+
+Source
+------
+
+`squarewell.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/squarewell.py>`_
+
+Authorship and Verification
+----------------------------
+
+* **Author:** 
+* **Last Modified by:** 
+* **Last Reviewed by:** 
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/stacked_disks.py
===================================================================
--- sasmodels/models/stacked_disks.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/stacked_disks.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -102,4 +102,11 @@
    John Wiley and Sons, New York, 1955
 
+Source
+------
+
+`stacked_disks.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/stacked_disks.py>`_
+
+`stacked_disks.c <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/stacked_disks.c>`_
+
 Authorship and Verification
 ----------------------------
@@ -108,4 +115,5 @@
 * **Last Modified by:** Paul Butler and Paul Kienzle **Date:** November 26, 2016
 * **Last Reviewed by:** Paul Butler and Paul Kienzle **Date:** November 26, 2016
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/star_polymer.py
===================================================================
--- sasmodels/models/star_polymer.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/star_polymer.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -50,4 +50,11 @@
    B Ewen *Macromolecules*, 22, 468-472 (1989)
 
+Source
+------
+
+`star_polymer.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/star_polymer.py>`_
+
+`star_polymer.c <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/star_polymer.c>`_
+
 Authorship and Verification
 ----------------------------
@@ -56,4 +63,5 @@
 * **Last Modified by:** Paul Butler **Date:** Auguts 26, 2017
 * **Last Reviewed by:** Ziang Li and Richard Heenan **Date:** May 17, 2017
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/stickyhardsphere.py
===================================================================
--- sasmodels/models/stickyhardsphere.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/stickyhardsphere.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -63,5 +63,18 @@
 ----------
 
-S V G Menon, C Manohar, and K S Rao, *J. Chem. Phys.*, 95(12) (1991) 9186-9190
+.. [#] S V G Menon, C Manohar, and K S Rao, *J. Chem. Phys.*, 95(12) (1991) 9186-9190
+
+Source
+------
+
+`stickyhardsphere.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/stickyhardsphere.py>`_
+
+Authorship and Verification
+----------------------------
+
+* **Author:** 
+* **Last Modified by:** 
+* **Last Reviewed by:** 
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/surface_fractal.py
===================================================================
--- sasmodels/models/surface_fractal.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/surface_fractal.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -36,5 +36,20 @@
 ----------
 
-D Mildner and P Hall, *J. Phys. D: Appl. Phys.*, 19 (1986) 1535-1545
+.. [#] D Mildner and P Hall, *J. Phys. D: Appl. Phys.*, 19 (1986) 1535-1545
+
+Source
+------
+
+`surface_fractal.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/surface_fractal.py>`_
+
+`surface_fractal.c <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/surface_fractal.c>`_
+
+Authorship and Verification
+----------------------------
+
+* **Author:** 
+* **Last Modified by:** 
+* **Last Reviewed by:** 
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/teubner_strey.py
===================================================================
--- sasmodels/models/teubner_strey.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/teubner_strey.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -61,11 +61,22 @@
 ----------
 
-M Teubner, R Strey, *J. Chem. Phys.*, 87 (1987) 3195
+.. [#] M Teubner, R Strey, *J. Chem. Phys.*, 87 (1987) 3195
+.. [#] K V Schubert, R Strey, S R Kline and E W Kaler, *J. Chem. Phys.*, 101 (1994) 5343
+.. [#] H Endo, M Mihailescu, M. Monkenbusch, J Allgaier, G Gompper, D Richter, B Jakobs, T Sottmann, R Strey, and I Grillo, *J. Chem. Phys.*, 115 (2001), 580
 
-K V Schubert, R Strey, S R Kline and E W Kaler,
-*J. Chem. Phys.*, 101 (1994) 5343
+Source
+------
 
-H Endo, M Mihailescu, M. Monkenbusch, J Allgaier, G Gompper, D Richter,
-B Jakobs, T Sottmann, R Strey, and I Grillo, *J. Chem. Phys.*, 115 (2001), 580
+`teubner_strey.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/teubner_strey.py>`_
+
+`teubner_strey.c <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/teubner_strey.c>`_
+
+Authorship and Verification
+----------------------------
+
+* **Author:** 
+* **Last Modified by:** 
+* **Last Reviewed by:** 
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 from __future__ import division
Index: sasmodels/models/triaxial_ellipsoid.py
===================================================================
--- sasmodels/models/triaxial_ellipsoid.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/triaxial_ellipsoid.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -114,7 +114,12 @@
 ----------
 
-[1] Finnigan, J.A., Jacobs, D.J., 1971.
-*Light scattering by ellipsoidal particles in solution*,
-J. Phys. D: Appl. Phys. 4, 72-77. doi:10.1088/0022-3727/4/1/310
+.. [#] Finnigan, J.A., Jacobs, D.J., 1971. *Light scattering by ellipsoidal particles in solution*, J. Phys. D: Appl. Phys. 4, 72-77. doi:10.1088/0022-3727/4/1/310
+
+Source
+------
+
+`triaxial_ellipsoid.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/triaxial_ellipsoid.py>`_
+
+`triaxial_ellipsoid.c <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/triaxial_ellipsoid.c>`_
 
 Authorship and Verification
@@ -124,4 +129,5 @@
 * **Last Modified by:** Paul Kienzle (improved calculation) **Date:** April 4, 2017
 * **Last Reviewed by:** Paul Kienzle & Richard Heenan **Date:**  April 4, 2017
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/two_lorentzian.py
===================================================================
--- sasmodels/models/two_lorentzian.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/two_lorentzian.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -27,7 +27,16 @@
 None.
 
+Source
+------
+
+`two_lorentzian.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/two_lorentzian.py>`_
+
+Authorship and Verification
+----------------------------
+
 * **Author:** NIST IGOR/DANSE **Date:** pre 2010
 * **Last Modified by:** Piotr rozyczko **Date:** January 29, 2016
 * **Last Reviewed by:** Paul Butler **Date:** March 21, 2016
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/two_power_law.py
===================================================================
--- sasmodels/models/two_power_law.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/two_power_law.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -37,7 +37,16 @@
 None.
 
+Source
+------
+
+`two_power_law.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/two_power_law.py>`_
+
+Authorship and Verification
+----------------------------
+
 * **Author:** NIST IGOR/DANSE **Date:** pre 2010
 * **Last Modified by:** Wojciech Wpotrzebowski **Date:** February 18, 2016
 * **Last Reviewed by:** Paul Butler **Date:** March 21, 2016
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/unified_power_Rg.py
===================================================================
--- sasmodels/models/unified_power_Rg.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/unified_power_Rg.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -63,9 +63,20 @@
 ----------
 
-G Beaucage, *J. Appl. Cryst.*, 28 (1995) 717-728
+.. [#] G Beaucage, *J. Appl. Cryst.*, 28 (1995) 717-728
+.. [#] G Beaucage, *J. Appl. Cryst.*, 29 (1996) 134-146
+.. [#] B Hammouda, *Analysis of the Beaucage model, J. Appl. Cryst.*, (2010), 43, 1474-1478
 
-G Beaucage, *J. Appl. Cryst.*, 29 (1996) 134-146
+Source
+------
 
-B Hammouda, *Analysis of the Beaucage model, J. Appl. Cryst.*, (2010), 43, 1474-1478
+`unified_power_Rg.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/unified_power_Rg.py>`_
+
+Authorship and Verification
+----------------------------
+
+* **Author:** 
+* **Last Modified by:** 
+* **Last Reviewed by:** 
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/vesicle.py
===================================================================
--- sasmodels/models/vesicle.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/vesicle.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -60,4 +60,10 @@
    Sons, New York, (1955)
 
+Source
+------
+
+`vesicle.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/vesicle.py>`_
+
+`vesicle.c <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/vesicle.c>`_
 
 Authorship and Verification
@@ -67,4 +73,5 @@
 * **Last Modified by:** Paul Butler **Date:** March 20, 2016
 * **Last Reviewed by:** Paul Butler **Date:** September 7, 2018
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 

Index: sasmodels/models/raspberry.py
===================================================================
--- sasmodels/models/raspberry.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/raspberry.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -98,11 +98,20 @@
 ----------
 
-K Larson-Smith, A Jackson, and D C Pozzo, *Small angle scattering model for
-Pickering emulsions and raspberry particles*, *Journal of Colloid and Interface
-Science*, 343(1) (2010) 36-41
+.. [#] K Larson-Smith, A Jackson, and D C Pozzo, *Small angle scattering model for Pickering emulsions and raspberry particles*, *Journal of Colloid and Interface Science*, 343(1) (2010) 36-41
+
+Source
+------
+
+`raspberry.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/raspberry.py>`_
+
+`raspberry.c <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/raspberry.c>`_
+
+Authorship and Verification
+----------------------------
 
 * **Author:** Andrew Jackson **Date:** 2008
 * **Modified by:** Andrew Jackson **Date:** March 20, 2016
 * **Reviewed by:** Andrew Jackson **Date:** March 20, 2016
 """
 
@@ -98,11 +98,20 @@
 
 * **Author:** Andrew Jackson **Date:** 2008
-* **Modified by:** Andrew Jackson **Date:** March 20, 2016
-* **Reviewed by:** Andrew Jackson **Date:** March 20, 2016
+* **Last Modified by:** Andrew Jackson **Date:** March 20, 2016
+* **Last Reviewed by:** Andrew Jackson **Date:** March 20, 2016
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 
Index: sasmodels/models/spinodal.py
===================================================================
--- sasmodels/models/spinodal.py	(revision b297ba9e837aada12de87cd46ea7a01bfe549da7)
+++ sasmodels/models/spinodal.py	(revision 0507e09b26f5789862db8a175d64657cf4f3b829)
@@ -40,21 +40,20 @@
 ----------
 
-H. Furukawa. Dynamics-scaling theory for phase-separating unmixing mixtures:
-Growth rates of droplets and scaling properties of autocorrelation functions.
-Physica A 123, 497 (1984).
+.. [#] H. Furukawa. Dynamics-scaling theory for phase-separating unmixing mixtures: Growth rates of droplets and scaling properties of autocorrelation functions. Physica A 123, 497 (1984).
+.. [#] H. Meier & G. Strobl. Small-Angle X-ray Scattering Study of Spinodal Decomposition in Polystyrene/Poly(styrene-co-bromostyrene) Blends. Macromolecules 20, 649-654 (1987).
+.. [#] T. Hashimoto, M. Takenaka & H. Jinnai. Scattering Studies of Self-Assembling Processes of Polymer Blends in Spinodal Decomposition. J. Appl. Cryst. 24, 457-466 (1991).
 
-H. Meier & G. Strobl. Small-Angle X-ray Scattering Study of Spinodal
-Decomposition in Polystyrene/Poly(styrene-co-bromostyrene) Blends.
-Macromolecules 20, 649-654 (1987).
+Source
+------
 
-T. Hashimoto, M. Takenaka & H. Jinnai. Scattering Studies of Self-Assembling
-Processes of Polymer Blends in Spinodal Decomposition.
-J. Appl. Cryst. 24, 457-466 (1991).
+`spinodal.py <https://github.com/SasView/sasmodels/blob/master/sasmodels/models/spinodal.py>`_
 
-Revision History
-----------------
+Authorship and Verification
+----------------------------
 
 * **Author:**  Dirk Honecker **Date:** Oct 7, 2016
 * **Revised:** Steve King    **Date:** Oct 25, 2018
 """
 
@@ -40,21 +40,20 @@
 
-* **Author:**  Dirk Honecker **Date:** Oct 7, 2016
-* **Revised:** Steve King    **Date:** Oct 25, 2018
+* **Author:** Dirk Honecker **Date:** Oct 7, 2016
+* **Last Modified by:** Steve King **Date:** Oct 25, 2018
+* **Last Reviewed by:** Steve King **Date:** Oct 25, 2018
+* **Source added by :** Steve King **Date:** March 25, 2019
 """
 